package tpdv;

/**
 * Classe que representa uma especificao de um produto do catlogo de produtos.
 *
 * @author Craig Larman, Jacques Philippe Sauv, jacques@dsc.ufpb.br
 * @version 1.0
 */
class EspecificacaoDeProduto implements IEspecProduto {
    /**
     * O Universal Product Code (UPC) do produto.
     */
    private int upc;
    /**
     * O preo do produto.
     */
    private float preo;
    /**
     * A descrio do produto.
     */
    private String descrio;

    /**
     * Cria uma especificao de produto.
     * @param upc O Universal Product Code do produto.
     * @param preo O preo do produto.
     * @param descrio A descrio do produto.
     */
    public EspecificacaoDeProduto(int upc, float preo, String descrio) {
        this.upc = upc;
        this.preo = preo;
        this.descrio = descrio;
    }

    /**
     * Cria uma especificao de produto.
     * @param upc O Universal Product Code do produto.
     * @param preo O preo do produto.
     * @param descrio A descrio do produto.
     */
    public EspecificacaoDeProduto(int upc, double preo, String descrio) {
        this(upc, (float)preo, descrio);
    }

    /**
     * Obtem o Universal Product Code do produto.
     * @return O Universal Product Code do produto.
     */
    public int getUPC() { return upc; }

    /**
     * Obtem o preo do produto.
     * @return O preo do produto.
     */
    public float getPreo() { return preo; }

    /**
     * Obtem a descrio do produto.
     * @return A descrio do produto.
     */
    public String getDescrio() { return descrio; }
}
