package tpdv;

/**
 * Interface para qualquer tipo de Terminal Ponto De Venda (TPDV).
 * Um TPDV  usado para fazer uma venda (uma nica venda de cada vez).
 * Itens podem ser comprados at o final da venda.
 * Um pagamento pode ser feito para a venda corrente.
 *
 * @author Jacques Philippe Sauv, jacques@dsc.ufpb.br
 * @version 1.0
 */
public interface ITPDV {
    /**
     * Obtm a venda corrente sendo realizada pelo TPDV.
     * @return A venda corrente sendo realizada pelo TPDV.
     */
    IVenda getVenda();

    /**
     * Chamado para indicar que a venda terminou.
     */
    void fimDeVenda() throws NaoHaVendaException;

    /**
     * Chamado para adicionar  venda corrente um nmero de itens sendo comprados.
     * @param upc O Universal Product Code do item sendo comprado.
     * @param quantidade O nmero de itens sendo comprados.
     */
    void entraItem(int upc, int quantidade) throws ProdutoInexistenteException;
    
    /**
     * Realiza um pagamento para uma venda.
     * @param valorEntregue O valor entregue pelo cliente para pagar a venda.
     */
    void faaPagamento(float valorEntregue) throws PagamentoInsuficienteException;
}
