package tpdv;

/**
 * Classe que implementa uma Loja. Cada loja tem um catlogo de produtos e um nico TPDV.
 *
 * @author Craig Larman, Jacques Philippe Sauv, jacques@dsc.ufpb.br
 * @version 1.0
 */
public class Loja {
    /**
     * O catlogo de produtos da loja.
     */
    private ICatalogoDeProdutos catlogo;
    /**
     * O terminal ponto de venda (TPDV) da loja.
     * Uma loja s tem um nico TPDV.
     */
    private ITPDV tpdv;

    /**
     * Cria uma loja. O catlogo de produtos e o TPDV so automaticamente criados.
     * @param valorEntregue O valor entregue para pagar a venda.
     */
    public Loja() {
        catlogo = makeCatlogo();
        tpdv = makeTPDV(catlogo);
    }

    /**
     * Obtem o TPDV da loja.
     * @return O TPDV da loja.
     */
    public ITPDV getTPDV() { return tpdv; }

    /**
     * Obtem o catlogo de produtos da loja.
     * @return O catlogo de produtos da loja.
     */
    public ICatalogoDeProdutos getCatlogoDeProdutos() { return catlogo; }

    // factory methods
    protected ICatalogoDeProdutos makeCatlogo() {
        return new CatalogoDeProdutos();
    }

    protected ITPDV makeTPDV(ICatalogoDeProdutos catlogo) {
        return new TPDV(catlogo);
    }
}
