package tpdv;

import junit.framework.*;
import tpdv.*;

/**
 * Testes da classe TPDV.
 *
 */
public class TestaLoja extends TestCase {
	protected Loja loja1;

	public TestaLoja(String name) {
		super(name);
	}
	public static void main(String[] args) {
		junit.textui.TestRunner.run(suite());
	}
	protected void setUp() {
        loja1 = new Loja();
	}
	public static Test suite() {
		return new TestSuite(TestaLoja.class);
	}
	public void testConstrutor() {
        assert("1", !loja1.equals(null));
		TPDV tpdv = (TPDV)loja1.getTPDV();
        assert("2", !tpdv.equals(null));
        ICatalogoDeProdutos cp = loja1.getCatlogoDeProdutos();
        assert("3", !cp.equals(null));
		assert("4", tpdv.isNovaVenda());
    }
    public void testCatalogo() {
        ICatalogoDeProdutos cp = loja1.getCatlogoDeProdutos();
        IEspecProduto ep = null;
        try {
          ep = cp.getEspecificao(100);
        } catch(ProdutoInexistenteException e) {
            fail("getEspecificacao(100) nao deveria gerar exception");
        }
        assert("1", !ep.equals(null));
        assertEquals("2", 100, ep.getUPC());
        assertEquals("3", 1.99, ep.getPreo(), 0.001);
        assertEquals("4", "produto 1", ep.getDescrio());
    }
	public void testFazerVenda() {
		TPDV tpdv1 = (TPDV)loja1.getTPDV();
        try {
    		tpdv1.fimDeVenda();
            fail("fimDeVenda() deveria gerar exception");
        } catch(NaoHaVendaException e) {}
        try {
  		    tpdv1.entraItem(100, 1);
        } catch(ProdutoInexistenteException e) {
            fail("entraItem(100) nao deveria gerar exception");
        }
		assert("1", !tpdv1.isNovaVenda());
		assertEquals("2", 1.99, tpdv1.getVenda().total(), 0.001);
        try {
      		tpdv1.entraItem(200, 3);
        } catch(ProdutoInexistenteException e) {
            fail("entraItem(200) nao deveria gerar exception");
        }
		assert("3", !tpdv1.isNovaVenda());
		assertEquals("4", 12.46, tpdv1.getVenda().total(), 0.001);
        try {
    		tpdv1.faaPagamento((float)5.0);
            fail("facaPagamento(5.0) deveria gerar exception");
        } catch(PagamentoInsuficienteException e) {}
        try {
    		tpdv1.faaPagamento((float)20.0);
        } catch(PagamentoInsuficienteException e) {
          fail("facaPagamento(20.0) nao deveria gerar exception");
        }
		assertEquals("5", 7.54, tpdv1.getVenda().getTroco(), 0.001);
        try {
    		tpdv1.fimDeVenda();
        } catch(NaoHaVendaException e) {
          fail("fimDeVenda() nao deveria gerar exception");
        }
		assert("6", tpdv1.isNovaVenda());
    }
}